========
pySigmaP
========

.. image:: https://img.shields.io/badge/Made%20with-Python3-brightgreen.svg
        :target: https://www.python.org/
        :alt: made-with-python

.. image:: https://img.shields.io/pypi/v/pysigmap.svg
        :target: https://pypi.python.org/pypi/pysigmap

.. image:: https://img.shields.io/badge/License-BSD%202--Clause-brightgreen.svg
        :target: https://github.com/eamontoyaa/pysigmap/blob/master/LICENSE
        :alt: License

.. image:: https://readthedocs.org/projects/pysigmap/badge/?version=latest
        :target: https://pysigmap.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Open-source application software developed in Python3 for interpreting
the preconsolidation pressure of fine-grained soils in incremental loading
oedometer testing. pySigmaP includes nine methods such as the methods of Casagrande,
Pacheco-Silva, Butterfield, Oikawa, Becker et al., Morin, Onitsuka et al.,
Wang and Frost, and Boone.


* Free software: BSD 2-Clause License
* Documentation: https://pysigmap.readthedocs.io.


Features
--------

* `Documentation <https://pysigmap.readthedocs.io>`_
* `PyPI <https://pypi.org/project/pysigmap>`_
* `GitHub <https://github.com/eamontoyaa/pysigmap>`_
* Open source and free software: `BSD-2-Clause <https://opensource.org/licenses/BSD-2-Clause>`_.


References
----------


Becker, D. E., Crooks, J. H. A., Been, K., & Jefferies, M. G. (1987). Work as a
criterion for determining in situ and yield stresses in clays. Canadian
Geotechnical Journal, 24, 4, 549-564, https://doi.org/10.1139/t87-070.

Boone, S. J. (2010). A critical reappraisal of "preconsolidation
pressure" interpretations using the oedometer test. Canadian Geotechnical
Journal, 47, 3, 281-296. https://doi.org/10.1139/T09-093.

Butterfield, R. (1979). A natural compression law for soils (an advance on
e–log p'). Geotechnique, 29, 4, 469-480,
https://doi.org/10.1680/geot.1979.29.4.469.

Casagrande, A. (1936). The determination of pre-consolidation load and its
practical significance. In Proceedings of the First International Conference
on Soil Mechanins and Foundations Engineering, 3, 60-64.

Morin, P. (1988). Work as a criterion for determining in situ and yield
stresses in clays: Discussion. Canadian Geotechnical Journal, 25, 4, 845-847,
https://doi.org/10.1139/t88-096.

Oikawa, H. (1987). Compression Curve of Soft Soils. Soils and Foundations,
27, 3, 99-104, https://doi.org/10.3208/sandf1972.27.3_99.

Onitsuka, K., Hong, Z., Hara, Y., & Yoshitake, S. (1995). Interpretation of
Oedometer Test Data for Natural Clays. Soils and Foundations, 35, 3, 61-70,
https://doi.org/10.3208/sandf.35.61.

Pacheco Silva, F. 1970. A new graphical construction for determination of the
pre-consolidation stress of a soil sample. In Proceedings of the 4th Brazilian
Conference on Soil Mechanics and Foundation Engineering, Rio de Janeiro,
Brazil. Vol. 2, No.1, pp. 225–232.

Wang, L. B., & Frost, J. D. (2004). Dissipated strain energy method for
determining preconsolidation pressure. Canadian Geotechnical Journal, 41, 4,
760-768, https://doi.org/10.1139/t04-013.

